@@ -4,7 +4,7 @@ import traceback
 import sys
 
 from .handlers import Handlers
-from .dispatcher import Dispatcher
+from .dispatcher import Dispatcher, get_dispatcher_by_event
 
 
 class Handler:
@@ -18,6 +18,7 @@ class Bot:
         self.config = {}
         self.handlers = []
         self.middlewares = []
+        self.is_rejected = False
 
     def handle(self, handler: Handler) -> None:
         self.handlers.append(handler)
@@ -25,6 +26,9 @@ class Bot:
     def add_middleware(self, middleware) -> None:
         self.middlewares.append(middleware)
 
+    def reject(self):
+        self.is_rejected = True
+
     async def run_polling(self) -> None:
         async with aiohttp.ClientSession() as session:
             async with session.get("https://api.vk.com/method/groups.getLongPollServer",
@@ -54,17 +58,21 @@ class Bot:
                     except:
                         sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
-    async def send_event(self, updates):
-        tasks = [asyncio.create_task(middleware.pre(updates))
-                 for middleware in self.middlewares if middleware.event_type in (updates["type"], None)]
+    async def send_event(self, event):
+        tasks = [asyncio.create_task(middleware.pre(get_dispatcher_by_event(event, event["type"], self.token), self.reject))
+                 for middleware in self.middlewares if middleware.event_type in (event["type"], None)]
         await asyncio.gather(*tasks)
 
-        tasks = [asyncio.create_task(handler.new_event(self.token, updates))
-                 for handler in self.handlers if handler.event_type == updates["type"]]
+        if self.is_rejected:
+            self.is_rejected = False
+            return
+
+        tasks = [asyncio.create_task(handler.new_event(self.token, event))
+                 for handler in self.handlers if handler.event_type == event["type"]]
         await asyncio.gather(*tasks)
 
-        tasks = [asyncio.create_task(middleware.post(updates))
-                 for middleware in self.middlewares if middleware.event_type in (updates["type"], None)]
+        tasks = [asyncio.create_task(middleware.post(get_dispatcher_by_event(event, event["type"], self.token)))
+                 for middleware in self.middlewares if middleware.event_type in (event["type"], None)]
         await asyncio.gather(*tasks)
 
     async def execute(self, method: str, **params) -> dict:
