@@ -16,16 +16,16 @@ class Handler:
         self.func = func
 
     def __call__(self, func):
-        async def wrapper(event: dict, token: str, text: str = None, user_id: int = None, peer_id: int = None, owner_id: int = None, post_id: int = None):
-            await func(Dispatcher(event, token, text, user_id, peer_id=peer_id, post_id=post_id, owner_id=owner_id))
+        async def wrapper(event: dict, token: str, text: str = None, user_id: int = None, peer_id: int = None, post_id: int = None, owner_id: int = None):
+            await func(Dispatcher(event=event, token=token, text=text, user_id=user_id, peer_id=peer_id, post_id=post_id, owner_id=owner_id))
 
         return type(self)(self.condition, self.is_lower, wrapper)
 
 
 class CustomHandler(Handler):
     def __call__(self, func):
-        async def wrapper(event: dict, token: str, text: str = None, user_id: int = None, peer_id: int = None, owner_id: int = None, post_id: int = None):
-            await func(Dispatcher(event, token, text, user_id, peer_id=peer_id, post_id=post_id, owner_id=owner_id))
+        async def wrapper(event: dict, token: str, text: str = None, user_id: int = None, peer_id: int = None, post_id: int = None, owner_id: int = None):
+            await func(Dispatcher(event=event, token=token, text=text, user_id=user_id, peer_id=peer_id, post_id=post_id, owner_id=owner_id))
 
         handler = CustomHandler(self.condition, self.is_lower, wrapper)
         handler.event_type = self.event_type
